#!/bin/sh
################################################################################
# run_cryosys.sh
#
# Launches the cryosys application, or processes an override package instead if
# present on a connected USB stick.
#
# SVN Keywords
# $HeadURL: http://nanoscience.oxinst.com/svn/Mercury/target_files/MercuryTarget/opt/OxfordInstruments/cryosys/run_cryosys.sh $
# $Author: grzybr $
# $Revision: 6789 $
# $Date: 2015-12-10 09:50:34 +0000 (Thu, 10 Dec 2015) $
#
# Copyright 2012 - Oxford Instruments
# This material is protected by copyright law. It is unlawful to copy it.
#
# This document contains confidential information. It is not to be disclosed or
# used except in accordance with applicable contracts or agreements. This
# document must be rendered illegible when being discarded.
#
################################################################################

# Exit on error.
set -e

source /opt/OxfordInstruments/cryosys/utils.sh

LOG_LEVEL=$LL_TRACE
LOG_MSG_PREFIX="run_cryosys.sh"

USB_MOUNT_SCRIPT="$CRYOSYS_INSTALL_LOCN/usb.sh"
OVERRIDE_EXEC_SCRIPT="$CRYOSYS_INSTALL_LOCN/run_override.sh"

OVERRIDE_PKG_NAME="cryosys.override"

OVERRIDE_SYS_ERR_IMAGE="/etc/override_pkg_system_err.raw"

################################################################################
# Function Definitions
################################################################################

fnReallyRunCryosys()
################################################################################
{
    # Set the necessary environment variables
    export QWS_SIZE=480x272
    export QWS_MOUSE_PROTO="Tslib:/dev/input/event1"
    export TSDIR=/usr/lib/ts
    export TSLIB_CALIBRATE=/etc/pointercal
    export TSLIB_CONFFILE=/etc/ts.conf
    export TSLIB_PLUGINDIR=/usr/lib/ts
    export TSLIB_TSDEVICE=/dev/input/event1

    # Unpack an update tarball in $CRYOSYS_INSTALL_LOCN, but only if there's
    # only one candidate.
    cd "$CRYOSYS_INSTALL_LOCN"
    set +e
    local _MATCH_COUNT=`ls cryosys_update*.tar 2>/dev/null | wc -l`
    set -e
    if [ $_MATCH_COUNT -eq 1 ]; then
        local _UPDATE_TARBALL=`ls cryosys_update*.tar 2>/dev/null`
        mv -f "$_UPDATE_TARBALL" /
        cd /
        set +e
        tar -xvf "$_UPDATE_TARBALL"
        set -e
        rm "$_UPDATE_TARBALL"
    fi

    # update.sh can result in the existing /opt/OxfordInstruments/cryosys being
    # moved somewhere else, and a 'new' one appearing, so we can't rely on
    # operations to it that we've already performed still being in effect on
    # completion of update.sh.
    cd "$CRYOSYS_INSTALL_LOCN"
    sh update.sh
    # TODO. Why are we doing this? Write access for non-root users is surely
    # not a good thing. And why exec access for all but root? 0744 instead?
    chmod 677 "$USB_MOUNT_SCRIPT"

    # Run cryosys
    cd "$CRYOSYS_INSTALL_LOCN"
    if [ -f cryosys ]; then       
        chmod a+x cryosys
        ./cryosys -graphicssystem openvg &
    else
        exit 1
    fi
}

################################################################################
# Entry
################################################################################

cd "$CRYOSYS_INSTALL_LOCN"

if [ ! -d "$USB_MOUNT_POINT" ]
then
    mkdir "$USB_MOUNT_POINT"
fi
# TODO. Why are we doing this? Write access for non-root users is surely not a
# good thing. And why exec access for all but root? 0744 instead?
chmod 677 "$USB_MOUNT_SCRIPT"

# If there's possibly a USB mass storage device attached then give it a while
# to get mounted.
if [ -e "/proc/scsi/usb-storage" ]; then
    fnLog $LL_TRACE "USB mass storage device detected. Waiting for mount."
    COUNT=0
    fnTestIfUSBStickMounted NOW_MOUNTED
    while [ "$NOW_MOUNTED" != "y" -a $COUNT -lt 10 ]; do
        COUNT=`expr $COUNT + 1`
        sleep 1s
        fnTestIfUSBStickMounted NOW_MOUNTED
    done
    if [ "$NOW_MOUNTED" = "y" ]; then
        fnLog $LL_TRACE "Mounted."
    else
        fnLog $LL_TRACE "Giving up wait for mount."
    fi
fi

if [ -f "$USB_MOUNT_POINT/$OVERRIDE_PKG_NAME" ]; then
    fnLog $LL_PROGRESS "An override package is present."
    /bin/touch /tmp/stopStartupProgress
    if [ -f "$OVERRIDE_EXEC_SCRIPT" ]; then
        fnLog $LL_TRACE "Launching override execution script."
        sh "$OVERRIDE_EXEC_SCRIPT" &
    else
        fnLog $LL_OUTCOME "Error: The override execution script ($OVERRIDE_EXEC_SCRIPT) is missing."
        fnShowImage "$OVERRIDE_SYS_ERR_IMAGE"
        exit 1
    fi
else
    fnLog $LL_TRACE "No override package present. Proceeding with cryosys launch."
    fnReallyRunCryosys
fi

exit 0
