################################################################################
# utils.sh
#
# Utility functions common to multiple cryosys scripts.
# Include in sh shell scripts with "source utils.sh".
#
# SVN Keywords
# $HeadURL: http://nanoscience.oxinst.com/svn/Mercury/target_files/MercuryTarget/opt/OxfordInstruments/cryosys/utils.sh $
# $Author: robertsi $
# $Revision: 5114 $
# $Date: 2013-11-29 10:36:19 +0000 (Fri, 29 Nov 2013) $
#
# Copyright 2013 - Oxford Instruments
# This material is protected by copyright law. It is unlawful to copy it.
#
# This document contains confidential information. It is not to be disclosed or
# used except in accordance with applicable contracts or agreements. This
# document must be rendered illegible when being discarded.
#
################################################################################

CRYOSYS_INSTALL_LOCN="/opt/OxfordInstruments/cryosys"
USB_MOUNT_POINT="/mnt/usb"

fnTestIfUSBStickMounted()
# $1 - The name of the variable to be set with outcome ("y"/"n").
################################################################################
{
    local _RESULT_VAR=$1
    local _RESULT="y"

    set +e
    local _MOUNT_ENTRY=`mount | grep "$USB_MOUNT_POINT"`
    set -e
    if [ "$_MOUNT_ENTRY" = "" ]; then
        _RESULT="n"
    fi

    eval $_RESULT_VAR="'$_RESULT'"
}

# Including scripts which use the following fns (fnLog() and fnShowImage()) must
# define the variables:
#  LOG_MSG_PREFIX - Text to be prefixed to every logged message.
#  LOG_LEVEL      - Only messages at this level and lower are reported.

# Log levels:
LL_OUTCOME=0
LL_PROGRESS=1
LL_TRACE=2

fnLog()
# $1 - Log level of message
# $2 - Text to be logged.
# Including script must define the variables:
#  LOG_MSG_PREFIX - Text to be prefixed to every logged message.
#  LOG_LEVEL      - Only messages at this level and lower are reported.
################################################################################
{
    if [ $1 -le $LOG_LEVEL ]; then
        /usr/bin/logger -s "$LOG_MSG_PREFIX: $2"
    fi
}

FB_DEV="/dev/fb0"

fnShowImage()
# $1 - Image file to display.
################################################################################
{
    if [ -f "$1" ]; then
        /bin/cat "$1" > "$FB_DEV"
    else
        fnLog $LL_OUTCOME "Error: Image $1 is missing."
    fi
}
